@@ -528,7 +528,7 @@ $body$#,
         FOR EACH ROW EXECUTE PROCEDURE disabled_to_zero()/,
 
     q/-- intervals
-      CREATE TABLE intervals (
+      CREATE TABLE IF NOT EXISTS intervals (
           iid        serial PRIMARY KEY,
           eid        integer REFERENCES employees (eid) NOT NULL,
           aid        integer REFERENCES activities (aid) NOT NULL,
@@ -539,6 +539,23 @@ $body$#,
           EXCLUDE USING gist (eid WITH =, intvl WITH &&)
       )/,
 
+    q/CREATE SEQUENCE temp_intvl_seq/,
+
+    q/COMMENT ON SEQUENCE temp_intvl_seq IS 'sequence guaranteeing that each set of temporary intervals will have a unique identifier'/,
+
+    q/-- tempintvls
+      -- for staging fillup intervals 
+      CREATE TABLE IF NOT EXISTS tempintvls (
+          int_id     serial PRIMARY KEY,
+          tiid       integer NOT NULL,
+          eid        integer REFERENCES employees (eid) NOT NULL,
+          aid        integer REFERENCES activities (aid) NOT NULL,
+          intvl      tstzrange NOT NULL,
+          long_desc  text,
+          remark     text,
+          EXCLUDE USING gist (tiid WITH =, intvl WITH &&)
+      )/,
+
     q#-- trigger function to ensure that a privhistory/schedhistory record
       -- does not fall within an existing attendance interval
     CREATE OR REPLACE FUNCTION history_policy() RETURNS trigger AS $$
@@ -647,9 +664,15 @@ $body$#,
     q/CREATE TRIGGER a1_interval_valid_intvl BEFORE INSERT OR UPDATE ON intervals
       FOR EACH ROW EXECUTE PROCEDURE valid_intvl()/,
 
+    q/CREATE TRIGGER a1_interval_valid_intvl BEFORE INSERT OR UPDATE ON tempintvls
+      FOR EACH ROW EXECUTE PROCEDURE valid_intvl()/,
+
     q/CREATE TRIGGER a2_interval_not_too_future BEFORE INSERT OR UPDATE ON intervals
       FOR EACH ROW EXECUTE PROCEDURE not_too_future()/,
 
+    q/CREATE TRIGGER a2_interval_not_too_future BEFORE INSERT OR UPDATE ON tempintvls
+      FOR EACH ROW EXECUTE PROCEDURE not_too_future()/,
+
     q/CREATE TRIGGER a3_no_iid_update BEFORE UPDATE ON intervals
       FOR EACH ROW EXECUTE PROCEDURE iid_immutable()/,
     
